@@ -1,6 +1,6 @@
 /** \file gphoto2-port-log.h
  *
- * Copyright © 2001 Lutz Müller <lutz@users.sf.net>
+ * Copyright 2001 Lutz Mueller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,7 +42,9 @@
 # endif
 # define IOLIBS			"."
 # define strcasecmp		_stricmp
-# define snprintf		_snprintf
+# ifndef snprintf
+#  define snprintf		_snprintf
+# endif
 
 /* Work-around for readdir() */
 typedef struct {
@@ -55,14 +57,14 @@ typedef struct {
 	int  drive_index;
 } GPPORTWINDIR;
 
-/* Sleep functionality */
-# define GP_SYSTEM_SLEEP(_ms)	  do { Sleep(_ms); } while (0)
 
 /* Directory-oriented functions */
 # define gp_system_dir		  GPPORTWINDIR *
 # define gp_system_dirent	  WIN32_FIND_DATA *
 # define gp_system_dir_delim	  '\\'
 
+# define sleep(x) usleep((x) * 1000 * 1000)
+
 /************************************************************************
  * End WIN32 definitions
  ************************************************************************/
@@ -201,14 +203,6 @@ typedef struct {
 # include <sys/stat.h>
 # include <unistd.h>
 
-/** Sleep passed amount of milliseconds. */
-# define GP_SYSTEM_SLEEP(_ms)			      \
-  do {						      \
-    struct timespec req;			      \
-    req.tv_sec = 0;				      \
-    req.tv_nsec = 1000*1000*((long)(_ms));	      \
-    nanosleep(&req, NULL);			      \
-  } while (0)
 
 /* Directory-oriented functions */
 /** A system directory handle */
